# Pelink

TODO: Readme


# License

## Pelink

This project is licenced under the Mozilla Public License version 2.0. You may obtain a copy of the licence at the [LICENSE file in this repository](./LICENSE), or online at [https://www.mozilla.org/en-US/MPL/2.0/](https://www.mozilla.org/en-US/MPL/2.0/).


## MPV

Pelink uses [MPV](https://mpv.io/) as the media player through [libmpv](https://github.com/mpv-player/mpv/tree/master).

MPV is licensed under the GPLv2 "or later" by default, LGPLv2.1 "or later" with -Dgpl=false. See [details](https://github.com/mpv-player/mpv/blob/master/Copyright).

You can get the full license for MPV at https://github.com/mpv-player/mpv/blob/master/LICENSE.GPL


## Python-mpv

Pelink uses [python-mpv](https://pypi.org/project/python-mpv/) as the intermediary between Python and libmpv API.

Python-mpv inherits the underlying libmpv’s license, which can be either GPLv2 or later (default) or LGPLv2.1 or later. For details, [see the mpv copyright page](https://github.com/mpv-player/mpv/blob/master/Copyright).
